==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/STANDARDVALUE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour STANDARDVALUE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="STANDARDVALUE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDVALUE_Type", propOrder = {
    "standardquantity",
    "uomid"
})
public class STANDARDVALUE_Type {

    @XmlElement(name = "STANDARDQUANTITY", required = true)
    protected QUANTITY standardquantity;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;

    /**
     * Obtient la valeur de la propriété standardquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTANDARDQUANTITY() {
        return standardquantity;
    }

    /**
     * Définit la valeur de la propriété standardquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTANDARDQUANTITY(QUANTITY value) {
        this.standardquantity = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/STANDARDVALUE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for STANDARDVALUE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STANDARDVALUE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDVALUE_Type", propOrder = {
    "standardquantity",
    "uomid"
})
public class STANDARDVALUE_Type {

    @XmlElement(name = "STANDARDQUANTITY", required = true)
    protected QUANTITY standardquantity;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;

    /**
     * Gets the value of the standardquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTANDARDQUANTITY() {
        return standardquantity;
    }

    /**
     * Sets the value of the standardquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTANDARDQUANTITY(QUANTITY value) {
        this.standardquantity = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}
